==> nextcloud-24.0.9.tgz: nextcloud/apps/workflowengine/l10n/sc.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Cust'utèntzia no podet operare",
    "The given regular expression is invalid" : "Cust'espressione regulare no est bàlida",
    "The given file size is invalid" : "Custa mannària de archìviu no est bàlida",
    "The given tag id is invalid" : "Custa eticheta no est bàlida",
    "The given IP range is invalid" : "Custu grupu de IP no est bàlidu",
    "The given IP range is not valid for IPv4" : "Custu grupu de IP no est bàlidu pro IPv4",
    "The given IP range is not valid for IPv6" : "Custu grupu de IP no est bàlidu pro IPv6",
    "The given time span is invalid" : "Custu intervallu de tempus no est bàlidu",
    "The given start time is invalid" : "Custa ora de cumintzu no est bàlida",
    "The given end time is invalid" : "Custa ora de acabbu no est bàlida",
    "The given group does not exist" : "Custu grupu no esistit",
    "File" : "Archìviu",
    "File created" : "Archìviu creadu",
    "File updated" : "Archìviu agiornadu",
    "File renamed" : "Archìviu torradu a numenare",
    "File deleted" : "Archìviu cantzelladu",
    "File accessed" : "Fatu s'atzessu a s'archìviu",
    "File copied" : "Archìviu copiadu",
    "Tag assigned" : "Eticheta assignada",
    "Someone" : "Calecuna persone",
    "%s created %s" : "%s at creadu %s",
    "%s modified %s" : "%s at modificadu %s",
    "%s deleted %s" : "%s at cantzelladu %s",
    "%s accessed %s" : "%s at fatu s'atzessu in %s",
    "%s renamed %s" : "%s at torradu a numenare %s",
    "%s copied %s" : "%s at copiadu %s",
    "%s assigned %s to %s" : "%s at assignadu %s a %s",
    "Operation #%s does not exist" : "S'operatzione #%s no esistit",
    "Entity %s does not exist" : "S'entidade %s no esistit",
    "Entity %s is invalid" : "S'entidade %s no est bàlida",
    "No events are chosen." : "Perunu eventu seberadu",
    "Entity %s has no event %s" : "S'entidade %s no tenet eventos %s",
    "Operation %s does not exist" : "S'operatzione %s no esistit",
    "Operation %s is invalid" : "S'operatzione %s no est bàlida",
    "At least one check needs to be provided" : "Depet èssere frunidu a su mancu  unu controllu",
    "The provided operation data is too long" : "Is datos operativos frunidos sunt tropu longos",
    "Invalid check provided" : "Su controllu frunidu no est bàlidu",
    "Check %s does not exist" : "Su controllu %s no esistit",
    "Check %s is invalid" : "Su controllu %s no est bàlidu",
    "Check %s is not allowed with this entity" : "Su controllu %s no est permìtidu cun custa entidade",
    "The provided check value is too long" : "Su balore de su controllu frunidu est tropu longu",
    "Check #%s does not exist" : "Su controllu #%s no esistit",
    "Check %s is invalid or does not exist" : "Su controllu %s no est bàlidu o no esistit",
    "Flow" : "Flussu",
    "Nextcloud workflow engine" : "Motore de su flussu de traballu de Nextcloud",
    "Select a filter" : "Seletziona unu filtru",
    "Select a comparator" : "Seletziona unu cumparadore",
    "Select a file type" : "Seletziona una genia de archìviu",
    "e.g. httpd/unix-directory" : "pro esèmpiu httpd/unix-directory",
    "Folder" : "Cartella",
    "Images" : "Imàgines",
    "Office documents" : "Documentos de Office",
    "PDF documents" : "Documentos PDF",
    "Custom mimetype" : "Personaliza sa genia MIME",
    "Please enter a valid time span" : "Inserta•nche un'intervallu de tempus bàlidu",
    "Select a request URL" : "Seletziona unu URL de rechesta",
    "Predefined URLs" : "URL predefinidos",
    "Files WebDAV" : "Archìvios WebDAV",
    "Others" : "Àtere",
    "Custom URL" : "Personaliza URL",
    "Select a user agent" : "Seletziona un'agente de utente",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de iscrivania",
    "Thunderbird & Outlook addons" : "Cumponente de agiunta de Thunderbird & Outlook",
    "Custom user agent" : "Personaliza agente de utente",
    "At least one event must be selected" : "Depet èssere seletzionadu a su mancu un'eventu",
    "Add new flow" : "Agiunghe flussu nou",
    "When" : "Cando",
    "and" : "e",
    "Cancel" : "Annulla",
    "Delete" : "Cantzella",
    "The configuration is invalid" : "Sa cunfiguratzione no est bàlida",
    "Active" : "Ativu",
    "Save" : "Sarva",
    "Available flows" : "Flussos a disponimentu",
    "For details on how to write your own flow, check out the development documentation." : "Pro detàllios subra comente iscriere su flussu tuo etotu, controlla sa documentatzione de isvilupu.",
    "More flows" : "Àteros flussos",
    "Browse the App Store" : "Esplora sa butega de is aplicatziones",
    "Show less" : "Mustra prus pagu",
    "Show more" : "Mustra de prus",
    "Configured flows" : "Flussos cunfigurados",
    "Your flows" : "Flussos tuos",
    "matches" : "currispondèntzias",
    "does not match" : "no currispondet",
    "is" : "est",
    "is not" : "no est",
    "File name" : "Nùmene de archìviu",
    "File MIME type" : "Genia de archìviu MIME",
    "File size (upload)" : "Mannària de s'archìviu (carrigamentu)",
    "less" : "prus pagu",
    "less or equals" : "prus pagu o uguale",
    "greater or equals" : "prus mannu o uguale",
    "greater" : "prus mannu",
    "Request remote address" : "Indiritzu dae tesu de sa rechesta",
    "matches IPv4" : "currispondet a IPv4",
    "does not match IPv4" : "no currispondet a IPv4",
    "matches IPv6" : "currispondet a IPv6",
    "does not match IPv6" : "no currispondet a IPv6",
    "File system tag" : "Eticheta de archìviu de sistema",
    "is tagged with" : "est etichetadu cun",
    "is not tagged with" : "no est etichetadu cun",
    "Request URL" : "URL de sa rechesta",
    "Request time" : "Ora de sa rechesta",
    "between" : "cumprèndidu tra",
    "not between" : "no cumprèndidu tra",
    "Request user agent" : "Agente de utente de sa rechesta",
    "User group membership" : "Apartenèntzia de is utentes a is grupos",
    "is member of" : "partètzipat a",
    "is not member of" : "no partètzipat a",
    "Select a tag" : "Seletziona un'eticheta",
    "No results" : "Perunu resurtadu",
    "%s (invisible)" : "%s (invisìbile)",
    "%s (restricted)" : "%s (limitadu)"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.7.tgz: nextcloud/apps/workflowengine/l10n/sc.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Cust'utèntzia no podet operare",
    "The given regular expression is invalid" : "Cust'espressione regulare no est bàlida",
    "The given file size is invalid" : "Custa mannària de archìviu no est bàlida",
    "The given tag id is invalid" : "Custa eticheta no est bàlida",
    "The given IP range is invalid" : "Custu grupu de IP no est bàlidu",
    "The given IP range is not valid for IPv4" : "Custu grupu de IP no est bàlidu pro IPv4",
    "The given IP range is not valid for IPv6" : "Custu grupu de IP no est bàlidu pro IPv6",
    "The given time span is invalid" : "Custu intervallu de tempus no est bàlidu",
    "The given start time is invalid" : "Custa ora de cumintzu no est bàlida",
    "The given end time is invalid" : "Custa ora de acabbu no est bàlida",
    "The given group does not exist" : "Custu grupu no esistit",
    "File" : "Archìviu",
    "File created" : "Archìviu creadu",
    "File updated" : "Archìviu agiornadu",
    "File renamed" : "Archìviu torradu a numenare",
    "File deleted" : "Archìviu cantzelladu",
    "File accessed" : "Fatu s'atzessu a s'archìviu",
    "File copied" : "Archìviu copiadu",
    "Tag assigned" : "Eticheta assignada",
    "Someone" : "Calecuna persone",
    "%s created %s" : "%s at creadu %s",
    "%s modified %s" : "%s at modificadu %s",
    "%s deleted %s" : "%s at cantzelladu %s",
    "%s accessed %s" : "%s at fatu s'atzessu in %s",
    "%s renamed %s" : "%s at torradu a numenare %s",
    "%s copied %s" : "%s at copiadu %s",
    "%s assigned %s to %s" : "%s at assignadu %s a %s",
    "Operation #%s does not exist" : "S'operatzione #%s no esistit",
    "Entity %s does not exist" : "S'entidade %s no esistit",
    "Entity %s is invalid" : "S'entidade %s no est bàlida",
    "No events are chosen." : "Perunu eventu seberadu",
    "Entity %s has no event %s" : "S'entidade %s no tenet eventos %s",
    "Operation %s does not exist" : "S'operatzione %s no esistit",
    "Operation %s is invalid" : "S'operatzione %s no est bàlida",
    "At least one check needs to be provided" : "Depet èssere frunidu a su mancu  unu controllu",
    "The provided operation data is too long" : "Is datos operativos frunidos sunt tropu longos",
    "Invalid check provided" : "Su controllu frunidu no est bàlidu",
    "Check %s does not exist" : "Su controllu %s no esistit",
    "Check %s is invalid" : "Su controllu %s no est bàlidu",
    "Check %s is not allowed with this entity" : "Su controllu %s no est permìtidu cun custa entidade",
    "The provided check value is too long" : "Su balore de su controllu frunidu est tropu longu",
    "Check #%s does not exist" : "Su controllu #%s no esistit",
    "Check %s is invalid or does not exist" : "Su controllu %s no est bàlidu o no esistit",
    "Flow" : "Flussu",
    "Nextcloud workflow engine" : "Motore de su flussu de traballu de Nextcloud",
    "Select a filter" : "Seletziona unu filtru",
    "Select a comparator" : "Seletziona unu cumparadore",
    "Select a file type" : "Seletziona una genia de archìviu",
    "e.g. httpd/unix-directory" : "pro esèmpiu httpd/unix-directory",
    "Folder" : "Cartella",
    "Images" : "Imàgines",
    "Office documents" : "Documentos de Office",
    "PDF documents" : "Documentos PDF",
    "Custom mimetype" : "Personaliza sa genia MIME",
    "Please enter a valid time span" : "Inserta•nche un'intervallu de tempus bàlidu",
    "Select a request URL" : "Seletziona unu URL de rechesta",
    "Files WebDAV" : "Archìvios WebDAV",
    "Custom URL" : "Personaliza URL",
    "Select a user agent" : "Seletziona un'agente de utente",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de iscrivania",
    "Thunderbird & Outlook addons" : "Cumponente de agiunta de Thunderbird & Outlook",
    "Custom user agent" : "Personaliza agente de utente",
    "At least one event must be selected" : "Depet èssere seletzionadu a su mancu un'eventu",
    "Add new flow" : "Agiunghe flussu nou",
    "When" : "Cando",
    "and" : "e",
    "Cancel" : "Annulla",
    "Delete" : "Cantzella",
    "The configuration is invalid" : "Sa cunfiguratzione no est bàlida",
    "Active" : "Ativu",
    "Save" : "Sarva",
    "Available flows" : "Flussos a disponimentu",
    "For details on how to write your own flow, check out the development documentation." : "Pro detàllios subra comente iscriere su flussu tuo etotu, controlla sa documentatzione de isvilupu.",
    "More flows" : "Àteros flussos",
    "Browse the App Store" : "Esplora sa butega de is aplicatziones",
    "Show less" : "Mustra prus pagu",
    "Show more" : "Mustra de prus",
    "Configured flows" : "Flussos cunfigurados",
    "Your flows" : "Flussos tuos",
    "matches" : "currispondèntzias",
    "does not match" : "no currispondet",
    "is" : "est",
    "is not" : "no est",
    "File name" : "Nùmene de archìviu",
    "File MIME type" : "Genia de archìviu MIME",
    "File size (upload)" : "Mannària de s'archìviu (carrigamentu)",
    "less" : "prus pagu",
    "less or equals" : "prus pagu o uguale",
    "greater or equals" : "prus mannu o uguale",
    "greater" : "prus mannu",
    "Request remote address" : "Indiritzu dae tesu de sa rechesta",
    "matches IPv4" : "currispondet a IPv4",
    "does not match IPv4" : "no currispondet a IPv4",
    "matches IPv6" : "currispondet a IPv6",
    "does not match IPv6" : "no currispondet a IPv6",
    "File system tag" : "Eticheta de archìviu de sistema",
    "is tagged with" : "est etichetadu cun",
    "is not tagged with" : "no est etichetadu cun",
    "Request URL" : "URL de sa rechesta",
    "Request time" : "Ora de sa rechesta",
    "between" : "cumprèndidu tra",
    "not between" : "no cumprèndidu tra",
    "Request user agent" : "Agente de utente de sa rechesta",
    "User group membership" : "Apartenèntzia de is utentes a is grupos",
    "is member of" : "partètzipat a",
    "is not member of" : "no partètzipat a",
    "Select a tag" : "Seletziona un'eticheta",
    "No results" : "Perunu resurtadu",
    "%s (invisible)" : "%s (invisìbile)",
    "%s (restricted)" : "%s (limitadu)",
    "Predefined URLs" : "URL predefinidos",
    "Others" : "Àtere"
},
"nplurals=2; plural=(n != 1);");
